@@ -1,6 +1,6 @@
 package Date::Exception;
 
-$Date::Exception::VERSION   = '0.03';
+$Date::Exception::VERSION   = '0.04';
 $Date::Exception::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Date::Exception - Base exception package as Moo Role for Date::* packages.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -46,7 +46,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Date-Exception>
+L<https://github.com/manwar/Date-Exception>
 
 =head1 BUGS
 
@@ -85,7 +85,7 @@ L<http://search.cpan.org/dist/Date-Exception/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2015 Mohammad S Anwar.
+Copyright (C) 2015 - 2016 Mohammad S Anwar.
 
 This  program  is  free software; you can redistribute it and/or  modify it under
 the  terms  of the the Artistic License (2.0).  You may obtain a copy of the full
