@@ -1,6 +1,6 @@
 package Date::Exception::InvalidYear;
 
-$Date::Exception::InvalidYear::VERSION   = '0.03';
+$Date::Exception::InvalidYear::VERSION   = '0.04';
 $Date::Exception::InvalidYear::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Date::Exception::InvalidYear - Handles 'invalid year' exception.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -33,7 +33,7 @@ Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
-L<https://github.com/Manwar/Date-Exception>
+L<https://github.com/manwar/Date-Exception>
 
 =head1 BUGS
 
@@ -72,7 +72,7 @@ L<http://search.cpan.org/dist/Date-Exception/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2015 Mohammad S Anwar.
+Copyright (C) 2015 - 2016 Mohammad S Anwar.
 
 This  program  is  free software; you can redistribute it and/or  modify it under
 the  terms  of the the Artistic License (2.0).  You may obtain a copy of the full
